==> classicperipherals-0.2.3-fabric-1.20.1-sources.jar: me/alexdevs/classicPeripherals/datagen/generators/RecipeGenerator.java <==
package me.alexdevs.classicPeripherals.datagen.generators;

import dan200.computercraft.api.ComputerCraftTags;
import dan200.computercraft.shared.ModRegistry;
import me.alexdevs.classicPeripherals.block.ModBlocks;
import me.alexdevs.classicPeripherals.item.ModItems;
import me.alexdevs.classicPeripherals.recipe.ModRecipes;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricRecipeProvider;
import net.minecraft.class_1802;
import net.minecraft.class_2444;
import net.minecraft.class_2447;
import net.minecraft.class_2450;
import net.minecraft.class_2456;
import net.minecraft.class_3489;
import net.minecraft.class_7800;
import net.minecraft.data.recipes.*;
import java.util.function.Consumer;

public class RecipeGenerator extends FabricRecipeProvider {
    public RecipeGenerator(FabricDataOutput output) {
        super(output);
    }

    @Override
    public void method_10419(Consumer<class_2444> builder) {

        class_2447.method_10437(class_7800.field_40636, ModBlocks.TOWER_BASE)
                .method_10439("ici")
                .method_10439("iai")
                .method_10439("ImI")
                .method_10434('i', class_1802.field_8620)
                .method_10434('c', ModRegistry.Items.CABLE.get())
                .method_10434('a', class_1802.field_27063)
                .method_10434('I', class_1802.field_8773)
                .method_10433('m', ComputerCraftTags.Items.WIRED_MODEM)
                .method_10429("has_modem", method_10420(ComputerCraftTags.Items.WIRED_MODEM))
                .method_10431(builder);

        class_2447.method_10437(class_7800.field_40636, ModBlocks.TOWER_SEGMENT)
                .method_10439("ici")
                .method_10439("ici")
                .method_10439("ici")
                .method_10434('i', class_1802.field_8076)
                .method_10434('c', ModRegistry.Items.CABLE.get())
                .method_10429("has_tower_base", method_10426(ModBlocks.TOWER_BASE))
                .method_10431(builder);

        class_2447.method_10437(class_7800.field_40636, ModBlocks.TOWER_HEAD)
                .method_10439("cmc")
                .method_10439("msm")
                .method_10439("cmc")
                .method_10434('s', ModBlocks.TOWER_SEGMENT)
                .method_10434('m', ModRegistry.Items.WIRELESS_MODEM_ADVANCED.get())
                .method_10434('c', ModItems.COPPER_COIL)
                .method_10429("has_tower_segment", method_10426(ModBlocks.TOWER_SEGMENT))
                .method_10429("has_copper_coil", method_10426(ModItems.COPPER_COIL))
                .method_10431(builder);

        class_2447.method_10437(class_7800.field_40636, ModBlocks.ANTENNA)
                .method_10439(" m ")
                .method_10439("mcm")
                .method_10439(" M ")
                .method_10434('m', ModRegistry.Items.WIRELESS_MODEM_NORMAL.get())
                .method_10434('c', ModRegistry.Items.CABLE.get())
                .method_10433('M', ComputerCraftTags.Items.WIRED_MODEM)
                .method_10429("has_modem", method_10420(ComputerCraftTags.Items.WIRED_MODEM))
                .method_10431(builder);

        class_2447.method_10436(class_7800.field_40636, ModItems.COPPER_COIL, 2)
                .method_10439("ccc")
                .method_10439("cwc")
                .method_10439("ccc")
                .method_10433('w', class_3489.field_15537)
                .method_10434('c', class_1802.field_27022)
                .method_10429("has_copper", method_10426(class_1802.field_27022))
                .method_10431(builder);

        class_2447.method_10437(class_7800.field_40636, ModBlocks.NFC_READER)
                .method_10439("sss")
                .method_10439("srs")
                .method_10439("scs")
                .method_10434('s', class_1802.field_20391)
                .method_10434('r', class_1802.field_8725)
                .method_10434('c', ModItems.COPPER_COIL)
                .method_10429("has_copper", method_10426(class_1802.field_27022))
                .method_10431(builder);

        class_2450.method_10447(class_7800.field_40636, ModItems.NFC_CARD)
                .method_10454(class_1802.field_8407)
                .method_10454(class_1802.field_8725)
                .method_10454(class_1802.field_27022)
                .method_10442("has_copper", method_10426(class_1802.field_27022))
                .method_10431(builder);

        class_2456.method_10476(ModRecipes.NFC_CARD_DYE)
                .method_10475(builder, "nfc_card_dye");

        class_2447.method_10437(class_7800.field_40636, ModItems.RFID_BADGE)
                .method_10439(" n ")
                .method_10439("ncn")
                .method_10439(" n ")
                .method_10434('n', class_1802.field_8675)
                .method_10434('c', ModItems.COPPER_COIL)
                .method_10429("has_copper", method_10426(class_1802.field_27022))
                .method_10431(builder);

        class_2447.method_10437(class_7800.field_40636, ModBlocks.RFID_SCANNER)
                .method_10439("sss")
                .method_10439("scs")
                .method_10439("sss")
                .method_10434('s', class_1802.field_20391)
                .method_10434('c', ModItems.COPPER_COIL)
                .method_10429("has_copper", method_10426(class_1802.field_27022))
                .method_10431(builder);

        class_2456.method_10476(ModRecipes.RFID_BADGE_RECIPE)
                .method_10475(builder, "rfid_badge_dye");
    }
}

==> classicperipherals-0.2.8-fabric-1.21.1-sources.jar: me/alexdevs/classicPeripherals/datagen/generators/RecipeGenerator.java <==
package me.alexdevs.classicPeripherals.datagen.generators;

import dan200.computercraft.api.ComputerCraftTags;
import dan200.computercraft.shared.ModRegistry;
import me.alexdevs.classicPeripherals.block.ModBlocks;
import me.alexdevs.classicPeripherals.item.ModItems;
import me.alexdevs.classicPeripherals.recipe.NfcCardRecipe;
import me.alexdevs.classicPeripherals.recipe.RfidBadgeRecipe;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricRecipeProvider;
import net.minecraft.class_1802;
import net.minecraft.class_2447;
import net.minecraft.class_2450;
import net.minecraft.class_2456;
import net.minecraft.class_3489;
import net.minecraft.class_7225;
import net.minecraft.class_7800;
import net.minecraft.class_8790;
import net.minecraft.data.recipes.*;
import java.util.concurrent.CompletableFuture;

public class RecipeGenerator extends FabricRecipeProvider {

    public RecipeGenerator(FabricDataOutput output, CompletableFuture<class_7225.class_7874> registriesFuture) {
        super(output, registriesFuture);
    }

    @Override
    public void method_10419(class_8790 output) {

        class_2447.method_10437(class_7800.field_40636, ModBlocks.TOWER_BASE)
                .method_10439("ici")
                .method_10439("iai")
                .method_10439("ImI")
                .method_10434('i', class_1802.field_8620)
                .method_10434('c', ModRegistry.Items.CABLE.get())
                .method_10434('a', class_1802.field_27063)
                .method_10434('I', class_1802.field_8773)
                .method_10433('m', ComputerCraftTags.Items.WIRED_MODEM)
                .method_10429("has_modem", method_10420(ComputerCraftTags.Items.WIRED_MODEM))
                .method_10431(output);

        class_2447.method_10437(class_7800.field_40636, ModBlocks.TOWER_SEGMENT)
                .method_10439("ici")
                .method_10439("ici")
                .method_10439("ici")
                .method_10434('i', class_1802.field_8076)
                .method_10434('c', ModRegistry.Items.CABLE.get())
                .method_10429("has_tower_base", method_10426(ModBlocks.TOWER_BASE))
                .method_10431(output);

        class_2447.method_10437(class_7800.field_40636, ModBlocks.TOWER_HEAD)
                .method_10439("cmc")
                .method_10439("msm")
                .method_10439("cmc")
                .method_10434('s', ModBlocks.TOWER_SEGMENT)
                .method_10434('m', ModRegistry.Items.WIRELESS_MODEM_ADVANCED.get())
                .method_10434('c', ModItems.COPPER_COIL)
                .method_10429("has_tower_segment", method_10426(ModBlocks.TOWER_SEGMENT))
                .method_10429("has_copper_coil", method_10426(ModItems.COPPER_COIL))
                .method_10431(output);

        class_2447.method_10437(class_7800.field_40636, ModBlocks.ANTENNA)
                .method_10439(" m ")
                .method_10439("mcm")
                .method_10439(" M ")
                .method_10434('m', ModRegistry.Items.WIRELESS_MODEM_NORMAL.get())
                .method_10434('c', ModRegistry.Items.CABLE.get())
                .method_10433('M', ComputerCraftTags.Items.WIRED_MODEM)
                .method_10429("has_modem", method_10420(ComputerCraftTags.Items.WIRED_MODEM))
                .method_10431(output);

        class_2447.method_10436(class_7800.field_40636, ModItems.COPPER_COIL, 2)
                .method_10439("ccc")
                .method_10439("cwc")
                .method_10439("ccc")
                .method_10433('w', class_3489.field_15537)
                .method_10434('c', class_1802.field_27022)
                .method_10429("has_copper", method_10426(class_1802.field_27022))
                .method_10431(output);

        class_2447.method_10437(class_7800.field_40636, ModBlocks.NFC_READER)
                .method_10439("sss")
                .method_10439("srs")
                .method_10439("scs")
                .method_10434('s', class_1802.field_20391)
                .method_10434('r', class_1802.field_8725)
                .method_10434('c', ModItems.COPPER_COIL)
                .method_10429("has_copper", method_10426(class_1802.field_27022))
                .method_10431(output);

        class_2450.method_10447(class_7800.field_40636, ModItems.NFC_CARD)
                .method_10454(class_1802.field_8407)
                .method_10454(class_1802.field_8725)
                .method_10454(class_1802.field_27022)
                .method_10442("has_copper", method_10426(class_1802.field_27022))
                .method_10431(output);

        class_2456.method_10476(NfcCardRecipe::new)
                .method_53820(output, "nfc_card_dye");

        class_2447.method_10437(class_7800.field_40636, ModItems.RFID_BADGE)
                .method_10439(" n ")
                .method_10439("ncn")
                .method_10439(" n ")
                .method_10434('n', class_1802.field_8675)
                .method_10434('c', ModItems.COPPER_COIL)
                .method_10429("has_copper", method_10426(class_1802.field_27022))
                .method_10431(output);

        class_2447.method_10437(class_7800.field_40636, ModBlocks.RFID_SCANNER)
                .method_10439("sss")
                .method_10439("scs")
                .method_10439("sss")
                .method_10434('s', class_1802.field_20391)
                .method_10434('c', ModItems.COPPER_COIL)
                .method_10429("has_copper", method_10426(class_1802.field_27022))
                .method_10431(output);

        class_2456.method_10476(RfidBadgeRecipe::new)
                .method_53820(output, "rfid_badge_dye");
    }
}
